Keepalive

Trait Keepalive 

pub trait Keepalive: Send + Sync { }
Marker trait: the implementor keeps a backing memory allocation alive.

As long as a value implementing this trait exists, the memory region described by the containing KeepaliveLocalMemory is guaranteed to remain valid.

Implementors