RdmaLocalMemory

Trait RdmaLocalMemory 

pub trait RdmaLocalMemory:
    Send
    + Sync
    + Debug {
    // Required methods
    fn addr(&self) -> usize;
    fn size(&self) -> usize;
    fn read_at(&self, offset: usize, dst: &mut [u8]) -> Result<(), Error>;
    fn write_at(&self, offset: usize, src: &[u8]) -> Result<(), Error>;
}
Handle to a contiguous region of local memory.

Implementations must guarantee the underlying allocation is valid for the lifetime of the implementor.

Required Methods

fn addr(&self) -> usize

Starting virtual address of the memory region.

fn size(&self) -> usize

Size of the memory region in bytes.

fn read_at(&self, offset: usize, dst: &mut [u8]) -> Result<(), Error>

Copy dst.len() bytes from this memory region starting at offset into dst.

fn write_at(&self, offset: usize, src: &[u8]) -> Result<(), Error>

Copy src.len() bytes from src into this memory region starting at offset.

Implementors